==> apache-servicecomb-java-chassis-distribution-2.9.3-src.zip: apache-servicecomb-java-chassis-distribution-2.9.3-src/demo/demo-schema/src/main/java/org/apache/servicecomb/demo/CommonSchemaInterface.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.demo;

import org.apache.servicecomb.swagger.invocation.context.InvocationContext;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

import io.swagger.annotations.ApiOperation;

@RequestMapping("/CommonSchemaInterface")
public interface CommonSchemaInterface {
  @GetMapping(path = "testInvocationTimeout")
  String testInvocationTimeout(@RequestParam("timeout") long timeout, @RequestParam("name") String name);

  @GetMapping(path = "testInvocationTimeoutWithInvocation")
  @ApiOperation(value = "testInvocationTimeoutWithInvocation", nickname = "testInvocationTimeoutWithInvocation")
  String testInvocationTimeout(InvocationContext context, @RequestParam("timeout") long timeout,
      @RequestParam("name") String name);

  @GetMapping(path = "testInvocationTimeoutInClientWait")
  String testInvocationTimeoutInClientWait(@RequestParam("timeout") long timeout, @RequestParam("name") String name);
}

==> apache-servicecomb-java-chassis-distribution-3.3.0-src.zip: apache-servicecomb-java-chassis-distribution-3.3.0-src/demo/demo-schema/src/main/java/org/apache/servicecomb/demo/CommonSchemaInterface.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.demo;

import org.apache.servicecomb.swagger.invocation.context.InvocationContext;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

import io.swagger.v3.oas.annotations.Operation;

@RequestMapping("/CommonSchemaInterface")
public interface CommonSchemaInterface {
  @GetMapping(path = "testInvocationTimeout")
  String testInvocationTimeout(@RequestParam("timeout") long timeout, @RequestParam("name") String name);

  @GetMapping(path = "testInvocationTimeoutWithInvocation")
  @Operation(summary = "testInvocationTimeoutWithInvocation", operationId = "testInvocationTimeoutWithInvocation")
  String testInvocationTimeout(InvocationContext context, @RequestParam("timeout") long timeout,
      @RequestParam("name") String name);

  @GetMapping(path = "testInvocationTimeoutInClientWait")
  String testInvocationTimeoutInClientWait(@RequestParam("timeout") long timeout, @RequestParam("name") String name);
}
